"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var testUtils_1 = require("./testUtils");
describe('parser', function () {
    var children = { type: 'ReactNode', required: false, description: '', };
    it('should parse simple react class component', function () {
        testUtils_1.check('Column', {
            Column: {
                prop1: { type: 'string', required: false },
                prop2: { type: 'number' },
                prop3: { type: '() => void' },
                prop4: { type: '"option1" | "option2" | "option3"' },
            }
        });
    });
    it('should parse simple react class component as default export', function () {
        testUtils_1.check('ColumnWithDefaultExport', {
            Column: {
                prop1: { type: 'string', required: false },
                prop2: { type: 'number' },
                prop3: { type: '() => void' },
                prop4: { type: '"option1" | "option2" | "option3"' },
            }
        });
    });
    it('should parse simple react class component as default export only', function () {
        testUtils_1.check('ColumnWithDefaultExportOnly', {
            ColumnWithDefaultExportOnly: {
                prop1: { type: 'string', required: false },
                prop2: { type: 'number' },
                prop3: { type: '() => void' },
                prop4: { type: '"option1" | "option2" | "option3"' },
            }
        });
    });
    it('should parse simple react class component as default anonymous export', function () {
        testUtils_1.check('ColumnWithDefaultAnonymousExportOnly', {
            ColumnWithDefaultAnonymousExportOnly: {
                prop1: { type: 'string', required: false },
                prop2: { type: 'number' },
                prop3: { type: '() => void' },
                prop4: { type: '"option1" | "option2" | "option3"' },
            }
        });
    });
    it('should parse simple react class component with state', function () {
        testUtils_1.check('AppMenu', {
            AppMenu: {
                menu: { type: 'any' },
            }
        });
    });
    it('should parse simple react class component with picked properties', function () {
        // we are not able to get correct descriptions for prop1,prop2
        testUtils_1.check('ColumnWithPick', {
            Column: {
                prop1: { type: 'string', required: false, description: '' },
                prop2: { type: 'number', description: '' },
                propx: { type: 'number' },
            }
        });
    });
    it('should parse HOCs', function () {
        testUtils_1.check('ColumnHigherOrderComponent', {
            ColumnHigherOrderComponent1: {
                prop1: { type: 'string' },
            },
            ColumnHigherOrderComponent2: {
                prop1: { type: 'string' },
            },
            RowHigherOrderComponent1: {
                prop1: { type: 'string' },
            },
            RowHigherOrderComponent2: {
                prop1: { type: 'string' },
            },
            ColumnExternalHigherOrderComponent: {
                prop1: { type: 'string' },
            },
            RowExternalHigherOrderComponent: {
                prop1: { type: 'string' },
            }
        });
    });
    it('should parse component with inherited properties HtmlAttributes<any>', function () {
        testUtils_1.check('ColumnWithHtmlAttributes', {
            Column: {
                prop1: { type: 'string', required: false },
                prop2: { type: 'number' },
                // HtmlAttributes
                defaultChecked: {
                    type: 'boolean',
                    required: false,
                    description: ''
                }
                // ...
            }
        }, false);
    });
    it('should parse component without exported props interface', function () {
        testUtils_1.check('ColumnWithoutExportedProps', {
            Column: {
                prop1: { type: 'string', required: false },
                prop2: { type: 'number' },
            }
        });
    });
    it('should parse functional component exported as const', function () {
        testUtils_1.check('ConstExport', {
            Row: {
                prop1: { type: 'string', required: false },
                prop2: { type: 'number' },
            },
            // TODO: this wasn't there before, i would guess that that's correct
            test: {}
        }, false);
    });
    it('should parse react component with properties defined in external file', function () {
        testUtils_1.check('ExternalPropsComponent', {
            ExternalPropsComponent: {
                prop1: { type: 'string' },
            }
        });
    });
    it('should parse react component with properties extended from an external .tsx file', function () {
        testUtils_1.check('ExtendsExternalPropsComponent', {
            ExtendsExternalPropsComponent: {
                prop1: { type: 'number', required: false, description: 'prop1' },
                prop2: { type: 'string', required: false, description: 'prop2' },
            }
        });
    });
    it('should parse react component with properties defined as type', function () {
        testUtils_1.check('FlippableImage', {
            FlippableImage: {
                isFlippedX: { type: 'boolean', required: false },
                isFlippedY: { type: 'boolean', required: false },
            }
        }, false);
    });
    it('should parse react component with const definitions', function () {
        testUtils_1.check('InlineConst', {
            MyComponent: {
                foo: { type: 'any' },
            }
        });
    });
    it('should parse react component with default props', function () {
        testUtils_1.check('ComponentWithDefaultProps', {
            ComponentWithDefaultProps: {
                sampleDefaultFromJSDoc: { type: '"hello" | "goodbye"', required: true, defaultValue: "hello", description: 'sample with default value' },
                sampleTrue: { type: "boolean", required: false, defaultValue: "true" },
                sampleFalse: { type: "boolean", required: false, defaultValue: "false" },
                sampleString: { type: "string", required: false, defaultValue: "hello" },
                sampleObject: { type: "{ [key: string]: any; }", required: false, defaultValue: "{ a: '1', b: 2, c: true, d: false, e: undefined, f: null, g: { a: '1' } }" },
                sampleNull: { type: "null", required: false, defaultValue: "null" },
                sampleUndefined: { type: "any", required: false, defaultValue: "undefined" },
            }
        });
    });
    it('should parse react PureComponent', function () {
        testUtils_1.check('PureRow', {
            Row: {
                prop1: { type: 'string', required: false },
                prop2: { type: 'number' },
            }
        });
    });
    it('should parse react PureComponent - regression test', function () {
        testUtils_1.check('Regression_v0_0_12', {
            Zoomable: {
                originX: { type: 'number' },
                originY: { type: 'number' },
                scaleFactor: { type: 'number' }
            }
        }, false);
    });
    it('should parse react functional component', function () {
        testUtils_1.check('Row', {
            Row: {
                prop1: { type: 'string', required: false },
                prop2: { type: 'number' },
            }
        });
    });
    it('should parse react stateless component', function () {
        testUtils_1.check('Stateless', {
            Stateless: {
                myProp: { type: 'string' },
            }
        });
    });
    it('should parse react stateless component with default props', function () {
        testUtils_1.check('StatelessWithDefaultProps', {
            StatelessWithDefaultProps: {
                sampleJSDoc: { type: "string", required: false, defaultValue: "test" },
                sampleProp: { type: "string", required: false, defaultValue: "hello" },
            }
        });
    });
    it('should parse functional component component defined as function', function () {
        testUtils_1.check('FunctionDeclaration', {
            Jumbotron: {
                prop1: { type: "string", required: true },
            }
        });
    });
    it('should parse functional component component defined as const', function () {
        testUtils_1.check('FunctionalComponentAsConst', {
            Jumbotron: {
                prop1: { type: "string", required: true },
            }
        });
    });
    it('should parse functional component component defined as function as default export', function () {
        testUtils_1.check('FunctionDeclarationAsDefaultExport', {
            Jumbotron: {
                prop1: { type: "string", required: true },
            }
        });
    });
    it('should parse functional component component defined as const as default export', function () {
        testUtils_1.check('FunctionalComponentAsConstAsDefaultExport', {
            // in this case the component name is taken from the file name
            FunctionalComponentAsConstAsDefaultExport: {
                prop1: { type: "string", required: true },
            }
        }, true, 'Jumbotron description');
    });
    it('should parse functional component component defined as const as named export', function () {
        testUtils_1.check('FunctionalComponentAsConstAsNamedExport', {
            // in this case the component name is taken from the file name
            FunctionalComponentAsConstAsNamedExport: {
                prop1: { type: "string", required: true },
            }
        }, true, 'Jumbotron description');
    });
    describe('Parser options', function () {
        describe('Property filtering', function () {
            describe('children', function () {
                it('should ignore property "children" if not explicitly documented', function () {
                    testUtils_1.check('Column', {
                        Column: {
                            prop1: { type: 'string', required: false },
                            prop2: { type: 'number' },
                            prop3: { type: '() => void' },
                            prop4: { type: '"option1" | "option2" | "option3"' },
                        }
                    }, true);
                });
                it('should not ignore any property that is documented explicitly', function () {
                    testUtils_1.check('ColumnWithAnnotatedChildren', {
                        Column: {
                            children: { type: 'ReactNode', required: false, description: 'children description' },
                            prop1: { type: 'string', required: false },
                            prop2: { type: 'number' },
                            prop3: { type: '() => void' },
                            prop4: { type: '"option1" | "option2" | "option3"' }
                        }
                    }, true);
                });
            });
            describe('propsFilter method', function () {
                it('should apply filter function and filter components accordingly', function () {
                    var propFilter = function (prop, component) { return prop.name !== 'prop1'; };
                    testUtils_1.check('Column', {
                        Column: {
                            prop2: { type: 'number' },
                            prop3: { type: '() => void' },
                            prop4: { type: '"option1" | "option2" | "option3"' }
                        }
                    }, true, null, { propFilter: propFilter });
                });
                it('should apply filter function and filter components accordingly', function () {
                    var propFilter = function (prop, component) {
                        if (component.name === 'Column') {
                            return prop.name !== 'prop1';
                        }
                        return true;
                    };
                    testUtils_1.check('Column', {
                        Column: {
                            prop2: { type: 'number' },
                            prop3: { type: '() => void' },
                            prop4: { type: '"option1" | "option2" | "option3"' }
                        }
                    }, true, null, { propFilter: propFilter });
                    testUtils_1.check('AppMenu', {
                        AppMenu: {
                            menu: { type: 'any' },
                        }
                    }, true, null, { propFilter: propFilter });
                });
            });
            describe('skipPropsWithName', function () {
                it('should skip a single property in skipPropsWithName', function () {
                    var propFilter = { skipPropsWithName: 'prop1' };
                    testUtils_1.check('Column', {
                        Column: {
                            prop2: { type: 'number' },
                            prop3: { type: '() => void' },
                            prop4: { type: '"option1" | "option2" | "option3"' }
                        }
                    }, true, null, { propFilter: propFilter });
                });
                it('should skip multiple properties in skipPropsWithName', function () {
                    var propFilter = { skipPropsWithName: ['prop1', 'prop2'] };
                    testUtils_1.check('Column', {
                        Column: {
                            prop3: { type: '() => void' },
                            prop4: { type: '"option1" | "option2" | "option3"' }
                        }
                    }, true, null, { propFilter: propFilter });
                });
            });
            describe('skipPropsWithoutDoc', function () {
                it('should skip a properties without documentation', function () {
                    var propFilter = { skipPropsWithoutDoc: false };
                    testUtils_1.check('ColumnWithUndocumentedProps', {
                        Column: {
                            prop1: { type: 'string', required: false },
                            prop2: { type: 'number' }
                        }
                    }, true, null, { propFilter: propFilter });
                });
            });
        });
    });
});
//# sourceMappingURL=parser.js.map